Helptasker common
=================

[![Testing](https://github.com/helptasker/common/actions/workflows/testing.yml/badge.svg)](https://github.com/helptasker/common/actions/workflows/testing.yml)
[![codecov](https://codecov.io/github/helptasker/common/branch/main/graph/badge.svg?token=IZK3GQGU2U)](https://codecov.io/github/helptasker/common)
